tlslite.constants.CertificateType

Home | Trees | Indices | Help |
--- | --- | --- | --- | ---

Package tlslite :: Module constants :: Class CertificateType |
[hide private]
[frames] | no frames]

# Class CertificateType

source code

Class Variables | [hide private]
| openpgp = `1`
| x509 = `0`

Home | Trees | Indices | Help |
--- | --- | --- | --- | ---

Generated by Epydoc 3.0.1 on Wed Nov 12 16:23:49 2014 | http://epydoc.sourceforge.net